.. _libdoc_graph_graph:

==============================================
:mod:`graph` -- Interface for the Aesara graph
==============================================

---------
Reference
---------

.. automodule:: aesara.graph.basic
   :platform: Unix, Windows
   :synopsis: Interface for types of symbolic variables
   :members:
.. moduleauthor:: LISA
